nodes

package
v0.0.0-...-5bbec6f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 5, 2015 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Overview

Copyright 2014 Google Inc. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Node

type Node struct {
	// Hostname
	Name string `json:"name,omitempty"`
	// HostIP
	IP string `json:"ip,omitempty"`
}

type NodeList

type NodeList struct {
	Items []Node `json:"items,omitempty"`
}

NodeList contains the nodes that an instance of heapster is required to monitor.

type NodesApi

type NodesApi interface {
	// Returns a list of nodes that needs to be monitores or error on failure.
	List() (*NodeList, error)

	// Returns a string that contains internal debug information.
	DebugInfo() string
}

func NewExternalNodes

func NewExternalNodes() (NodesApi, error)

func NewKubeNodes

func NewKubeNodes(client *client.Client) (NodesApi, error)

Jump to